MusicXMl files in this directory are only permitted to be used
for research and development purpose.

## Notes

05_short.xml was made by modifying 05.xml from:
https://github.com/mmorise/kiritan_singing

song070_f00001_063.xml was taken from:
https://www.sinsy.jp/

haruga_kita.xml and yuki.xml were taken from:
http://onikuru.info/db-download/
